Module erlang_exif

Reads the Exif data from JPEG images.

Authors: Andre Nathan, Nathan Fiedler.

Description

Reads the Exif data from JPEG images.

Data Types

exif()

exif() = exif_map() | exif_dict()

exif_dict()

exif_dict() = dict:dict()

exif_map()

exif_map() = #{atom() => term()}

return_type()

return_type() = dict | maps

Function Index

read/1Read the Exif data from a named file (or binary data) and return a a map with the read data.
read/2Read the Exif data from a named file (or binary data) with data module specified.
read_binary/1Read the Exif data from a binary.
read_binary/2Read the Exif data from a binary and specify a data module.

Function Details

read/1

read(File) -> {ok, ExifMap} | {error, Reason}

Read the Exif data from a named file (or binary data) and return a a map with the read data.

read/2

read(File, ReturnType) -> {ok, Exif} | {error, Reason}

Read the Exif data from a named file (or binary data) with data module specified.

read_binary/1

read_binary(Data) -> {ok, Exif} | {error, Reason}

Read the Exif data from a binary.

read_binary/2

read_binary(Data, ReturnType) -> {ok, Exif} | {error, Reason}

Read the Exif data from a binary and specify a data module.


Generated by EDoc