Authors: Andre Nathan, Nathan Fiedler.
exif() = exif_map() | exif_dict()
exif_dict() = dict:dict()
exif_map() = #{atom() => term()}
return_type() = dict | maps
| read/1 | Read the Exif data from a named file (or binary data) and return a a map with the read data. |
| read/2 | Read the Exif data from a named file (or binary data) with data module specified. |
| read_binary/1 | Read the Exif data from a binary. |
| read_binary/2 | Read the Exif data from a binary and specify a data module. |
read(File) -> {ok, ExifMap} | {error, Reason}
Read the Exif data from a named file (or binary data) and return a a map with the read data.
read(File, ReturnType) -> {ok, Exif} | {error, Reason}
Read the Exif data from a named file (or binary data) with data module specified.
Read the Exif data from a binary.
read_binary(Data, ReturnType) -> {ok, Exif} | {error, Reason}
Read the Exif data from a binary and specify a data module.
Generated by EDoc